/*
 * <license header>
 */

import React from "react";
import { Provider, defaultTheme, Grid, View } from "@adobe/react-spectrum";
import ErrorBoundary from "react-error-boundary";
import { HashRouter as Router, Switch, Route } from "react-router-dom";
import { Home } from "./Home";

// Methods
// error handler on UI rendering failure
function onError(e, componentStack) {}

// component to show if UI fails rendering
function fallbackComponent({ componentStack, error }) {
  return (
    <>
      <h1 style={{ textAlign: "center", marginTop: "20px" }}>
        Something went wrong :(
      </h1>
      <pre>{componentStack + "\n" + error.message}</pre>
    </>
  );
}

function App(props) {
  //console.log("runtime object:", props.runtime);
  //console.log("ims object:", props.ims);

  // use exc runtime event handlers
  // respond to configuration change events (e.g. user switches org)
  props.runtime.on("configuration", ({ imsOrg, imsToken, locale }) => {
    console.log("configuration change", { imsOrg, imsToken, locale });
  });
  // respond to history change events
  props.runtime.on("history", ({ type, path }) => {
    console.log("history change", { type, path });
  });

  return (
    <ErrorBoundary onError={onError} FallbackComponent={fallbackComponent}>
      <Router>
        <Provider theme={defaultTheme} colorScheme={"light"}>
          <Route exact path="/">
            <Home runtime={props.runtime} ims={props.ims} />
          </Route>
        </Provider>
      </Router>
    </ErrorBoundary>
  );
}

export default App;
